TypedObjectWriter

Struct TypedObjectWriter 

pub struct TypedObjectWriter<'a, 'b> { /* private fields */ }
A writer for encoding the contents of a typed child object

Implementations

Source

impl TypedObjectWriter<'_, '_>

pub fn commit<T: AsRef<str>>(self, name: T)

Finalise this typed object, adding it to its parent If this is not called, the object will not be added