CustomDecoder

Trait CustomDecoder 

pub trait CustomDecoder {
    // Required method
    fn decode<'a>(
        &self,
        i: &'a [u8],
        dec: &mut AMF3Decoder,
    ) -> AMFResult<'a, Vec<Element>>;
}
A trait to define decoding for custom types for use with Externalized objects

Required Methods

fn decode<'a>( &self, i: &'a [u8], dec: &mut AMF3Decoder, ) -> AMFResult<'a, Vec<Element>>

This should implement the decoding of a given set of external elements Access to the AMF3Decoder is given to allow access to caches This implements the decoding side of externalized type support

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors