parse

Function parse 

pub fn parse(i: &[u8]) -> Result<Packet, Err<Error<'_>>>
Read a given slice as a packet

This function will return an error if the slice could not be parsed or if the entire slice was not consumed