parse_incomplete

Function parse_incomplete 

pub fn parse_incomplete(i: &[u8]) -> AMFResult<'_, Packet>
Read a given buffer as a packet

Unlike parse, this function will not error if the entire slice isn’t consumed and will return the data that was not parsed