Reader

Struct Reader 

pub struct Reader {
    pub amf3_decoder: AMF3Decoder,
    pub amf0_decoder: AMF0Decoder,
}
The main entry point of decoding an LSO file Example of use

use std::fs::File;
use std::io::Read;
use flash_lso::read::Reader;
let mut x = File::open("tests/sol/AS2-Demo.sol").expect("Couldn't open file");
let mut data = Vec::new();
let _ = x.read_to_end(&mut data).expect("Unable to read file");
let d = Reader::default().parse(&data).expect("Failed to parse lso file");
println!("{:#?}", d);

}

Fields

amf3_decoder: AMF3Decoder

Handles reading Amf3 data

amf0_decoder: AMF0Decoder

Handles reading Amf0 data

Implementations

Source

impl Reader

pub fn parse_header<'a>(&self, i: &'a [u8]) -> AMFResult<'a, Header>

Read a Lso header from the given slice

pub fn parse_incomplete<'a>(&mut self, i: &'a [u8]) -> AMFResult<'a, Lso>

Read a given buffer as an Lso

Unlike parse, this function will not error if the entire slice isn’t consumed and will return the data that was not parsed

pub fn parse<'a>(&mut self, i: &'a [u8]) -> Result<Lso, Err<Error<'a>>>

Read a given slice as an Lso

This function will return an error if the slice could not be parsed or if the entire slice was not consumed