Module types

Module types 

Types used for representing Lso contents

Structs

ClassDefinition
A class definition (trait) used in AMF3
CustomObjectValue
Represents the contents of a Custom object
DictionaryEntry
Represents a Key-Value pair in an AMF Dictionary
DictionaryObjectValue
The data contained within a Dictionary
ECMAArrayObjectValue
The contents of a ECMAArray object
Element
Represent a named element
Header
The header of a lso file
Lso
A container for lso files
ObjectId
A locally unique identifier for an Amf3 object
ObjectValue
The data contained within a Value of type Object
Reference
A reference to an existing value
VectorObjectValue
An AMF vector of Objects
VectorPrimitiveValue
An AMF vector of a some subtype

Enums

AMFVersion
The version of AMF being used
Attribute
Encodes the possible attributes that can be given to a trait
Value
A single or compound value