pub enum Attribute {
Dynamic,
External,
}Expand description
Encodes the possible attributes that can be given to a trait
Variants
Dynamic
If a trait is dynamic then the object it constructs may have additional properties other than the ones specified in the trait
External
If a trait is external then it requires custom serialization and deserialization support