ObjectId

Struct ObjectId 

pub struct ObjectId(pub i64);
A locally unique identifier for an Amf3 object

See the comment on Value::Amf3ObjectReference for details

Tuple Fields

0: i64

Implementations

Source

impl ObjectId

pub const INVALID: Self

An invalid object id

Use this when the id of an object can’t be known or will never need to be referenced (e.g. amf0) Unlike valid object id’s, multiple objects with an INVALID id are explicitly allowed Attempting to write a reference to an invalid object id is illegal and may error Attempting to write an object with an invalid object id is allowed, but it cannot be referenced later