Module write

Module write 

Writing of the Lso container format Handles writing of LSO files

Structs

Writer
Handles writing a given LSO

Functions

header_length
Get the serialized length of the header in bytes, this does not include the size of the header length field or the lso version marker
write_to_bytes
Write a LSO to a vec of bytes