header_length

Function header_length 

pub fn header_length(header: &Header) -> usize
Get the serialized length of the header in bytes, this does not include the size of the header length field or the lso version marker