Types used for representing Lso contents
Structs
- Class
Definition - A class definition (trait) used in AMF3
- Custom
Object Value - Represents the contents of a Custom object
- Dictionary
Entry - Represents a Key-Value pair in an AMF Dictionary
- Dictionary
Object Value - The data contained within a Dictionary
- ECMA
Array Object Value - The contents of a ECMAArray object
- Element
- Represent a named element
- Header
- The header of a lso file
- Lso
- A container for lso files
- Object
Id - A locally unique identifier for an Amf3 object
- Object
Value - The data contained within a Value of type Object
- Reference
- A reference to an existing value
- Vector
Object Value - An AMF vector of Objects
- Vector
Primitive Value - An AMF vector of a some subtype
Enums
- AMFVersion
- The version of AMF being used
- Attribute
- Encodes the possible attributes that can be given to a trait
- Value
- A single or compound value